@@ -12,41 +12,42 @@ setMethod("plotKML", "RasterBrickTimeSeries", function(
   pngheight = 180,
   pngpointsize = 14,
   kmz = get("kmz", envir = plotKML.opts),
+  open.kml = TRUE,
   ...
 ){
 
-  # sampling locations:
+  ## sampling locations:
   if(!("data" %in% slotNames(obj@sampled))){
     labs <- paste(obj@sampled@data[,1])
   } else {
     labs <- paste(1:length(obj@sampled))
   }
-  # Begin end times:
+  ## Begin end times:
   TimeSpan.begin <- obj@TimeSpan.begin
   TimeSpan.end <- obj@TimeSpan.end
-  # copy mean times:
+  ## copy mean times:
   obj@rasters <- setZ(obj@rasters, paste(as.POSIXct(unclass(as.POSIXct(TimeSpan.begin))+(unclass(as.POSIXct(TimeSpan.end))-unclass(as.POSIXct(TimeSpan.begin)))/2, origin="1970-01-01")))
   dtime = unclass(as.POSIXct(TimeSpan.end)) - unclass(as.POSIXct(TimeSpan.begin))
 
-  # open KML for writing:  
+  ## open KML for writing:  
   kml_open(folder.name = folder.name, file.name = file.name)
   
-  # add a description for the whole folder:
+  ## add a description for the whole folder:
   kml.out <- get("kml.out", envir=plotKML.fileIO)
   description_txt <- sprintf('<description>%s</description>', obj@rasters@title)
   parseXMLAndAdd(description_txt, parent=kml.out[["Document"]])  
   assign('kml.out', kml.out, envir=plotKML.fileIO)
   
-  # extract values at point locations:
+  ## extract values at point locations:
   ov <- extract(obj@rasters, obj@sampled)
   png_names <- paste(obj@variable, "_timeseries_", 1:nrow(ov), ".png", sep="")
   html.table <- paste('<img src="', png_names, '" height="', pngheight, '" width="', pngwidth, '" align ="middle" />', sep = '')
   kml_layer.SpatialPoints(obj = obj@sampled, points_names = labs, html.table = html.table)
   
-  # plot rasters:
+  ## plot rasters:
   kml_layer(obj = obj@rasters, dtime=dtime, ...) 
 
-  # plot the time-series data:
+  ## plot the time-series data:
   for(i in 1:nrow(ov)){
     png(filename=png_names[i], width=pngwidth, height=pngheight, bg="white", pointsize=pngpointsize)
     par(mar=c(4.5,4.5,.8,.8))
@@ -55,13 +56,17 @@ setMethod("plotKML", "RasterBrickTimeSeries", function(
     dev.off()
   }
   
-  # close the file:
+  ## close the file:
   kml_close(file.name = file.name)
   if (kmz == TRUE){
       kml_compress(file.name = file.name)
   }
-  # open KML file in the default browser:
-  kml_View(file.name)
+  ## open KML file in the default browser:
+  if(open.kml==TRUE){
+    kml_View(file.name)
+  } else {
+    message(paste("Object written to:", file.name))
+  }
   
 })
 
